@@ -13,7 +13,7 @@ use warnings;
 
 use base 'PDF::API2::Basic::PDF::Dict';
 
-our $VERSION = '2.044'; # VERSION
+our $VERSION = '2.046'; # VERSION
 
 use PDF::API2::Basic::PDF::Array;
 use PDF::API2::Basic::PDF::Dict;
@@ -132,15 +132,25 @@ sub add_page {
     my ($self, $page, $page_number) = @_;
     my $top = $self->get_top();
 
-    $page_number = -1 unless defined $page_number and $page_number <= $top->{'Count'}->val();
+    $page_number = -1 unless defined $page_number and $page_number < $top->{'Count'}->val();
 
     my $previous_page;
     if ($page_number == -1) {
-        $previous_page = $top->find_page($top->{'Count'}->val() - 1);
+        $previous_page = $top->{' last_page'};
+        unless (defined $previous_page) {
+            $previous_page = $top->find_page($top->{'Count'}->val() - 1);
+            $top->{' last_page'} = $page;
+        }
     }
     else {
         $page_number = $top->{'Count'}->val() + $page_number + 1 if $page_number < 0;
-        $previous_page = $top->find_page($page_number);
+        $page_number = 0 if $page_number < 0;
+        if ($top->{'Count'}->val() == scalar($top->{'Kids'}->realise->elements())) {
+            $previous_page = ($top->{'Kids'}->elements())[$page_number];
+        }
+        else {
+            $previous_page = $top->find_page($page_number);
+        }
     }
 
     my $parent;
@@ -180,7 +190,7 @@ sub add_page_recurse {
 
     my $parent = $self;
     my $max_kids_per_parent = 8; # Why?
-    if (scalar $parent->{'Kids'}->elements() >= $max_kids_per_parent and $parent->{'Parent'} and $page_index < 1) {
+    if (scalar $parent->{'Kids'}->elements() >= $max_kids_per_parent and $parent->{'Parent'} and $page_index == -1) {
         my $grandparent = $parent->{'Parent'}->realise();
         $parent = $parent->new($parent->_pdf(), $grandparent);
 
